<?php

namespace CRM\Controller;

use Zeedhi\Framework\DTO\Request;
use CRM\Traits\TResponse;
use CRM\Service\InterlocutoresClienteService;
use Zeedhi\Framework\DTO\Response;

class InterlocutoresClienteController
{

    protected $InterlocutoresClienteService;

    use TResponse;

    public function __construct(InterlocutoresClienteService $InterlocutoresClienteService)
    {
        $this->InterlocutoresClienteService = $InterlocutoresClienteService;
    }

    public function getInterlocutoresCliente(Request $request)
{
    try {
        // Chama o serviço e passa os parâmetros da requisição
        $data = $this->InterlocutoresClienteService->getInterlocutoresCliente($request->getParameters());
        
        // Envia resposta de sucesso
        $this->sendResponse($data, 200);
    } catch (\Exception $e) {
        // Envia resposta de erro em caso de exceção
        $this->sendResponse([
            'error' => $e->getMessage(), 
            'code' => $e->getCode()
        ], 500);
    }
}

public function getCliente()
{
    try {
        $data = $this->InterlocutoresClienteService->getCliente();
        $this->sendResponse($data, 200);
    } catch (\Exception $ex) {
        $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
    }
}

public function getInterlocutorBasedOnCliente(Request $request)
    {
        try {
            $data = $this->InterlocutoresClienteService->getInterlocutorBasedOnCliente($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    public function getCountry()
    {
        try {
            $data = $this->InterlocutoresClienteService->getCountry();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getState(Request $request)
    {
        try {
            $data = $this->InterlocutoresClienteService->getState($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getMunicipality(Request $request)
    {
        try {
            $data = $this->InterlocutoresClienteService->getMunicipality($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getNeighborhood(Request $request)
    {
        try {
            $data = $this->InterlocutoresClienteService->getNeighborhood($request->getParameters());
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveCrmInterloCli(Request $request)
    {
        try {
            $rows = $request->getParameters();
            $data = $this->InterlocutoresClienteService->saveCrmInterloCli($rows);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveEditCrmInterloCli(Request $request)
    {
        try {
            $rows = $request->getParameters();
            $data = $this->InterlocutoresClienteService->saveCrmInterloCli($rows);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function deleteCrmInterloCli(Request $request)
    {  
        try {
            $rows = $request->getParameters();
            $this->InterlocutoresClienteService->deleteCrmInterloCliService($rows);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }


}
