<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class CrmMotivoDeEvolucaoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCrmMotivoDeEvolucao()
    {
        $sql = "SELECT * FROM MOTIEVOLCONT ORDER BY CDMOTIEVOCON ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertCrmMotivoDeEvolucao( $params )
    {
        $sql = "INSERT INTO MOTIEVOLCONT
                       (CDMOTIEVOCON,
                        NMMOTIEVOCON,
                        IDENVIAEMAIL,
                        NRORG,
                        NRORGINCLUSAO,  
                        CDOPERINCLUSAO,
                        NRORGULTATU,  
                        CDOPERULTATU,    
                        IDATIVO,
                        DTINCLUSAO)        
                VALUES (:CDMOTIEVOCON,
                        :NMMOTIEVOCON,
                        :IDENVIAEMAIL,
                        :NRORG,
                        :NRORGINCLUSAO,  
                        :CDOPERINCLUSAO,
                        :NRORGULTATU,  
                        :CDOPERULTATU,    
                        :IDATIVO, 
                        SYSDATE)";
        $this->connection->executeStatement($sql, $params);
       
    }


    public function editCrmMotivoDeEvolucao( $params )
    {
        
        $sql = "UPDATE MOTIEVOLCONT
                SET 
                    NMMOTIEVOCON               = :NMMOTIEVOCON,
                    IDENVIAEMAIL               = :IDENVIAEMAIL,
                    NRORG                      = :NRORG,
                    NRORGULTATU                = :NRORGULTATU,  
                    CDOPERULTATU               = :CDOPERULTATU,  
                    IDATIVO                    = :IDATIVO,
                    DTULTATU                   = SYSDATE
                WHERE CDMOTIEVOCON             = :CDMOTIEVOCON";
        $this->connection->executeStatement($sql, $params);

    }

    public function checkExistingMotivoDeEvolucao($params)
    {
        $sql = "SELECT
                    COUNT(*) AS VALIDA
                FROM
                    MOTIEVOLCONT
                WHERE
                    UPPER (NMMOTIEVOCON) = UPPER (:NMMOTIEVOCON)
                    AND IDENVIAEMAIL  = :IDENVIAEMAIL 
                    AND NRORG = :NRORG  AND CDMOTIEVOCON <> :CDMOTIEVOCON";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }

    
    public function deleteCrmMotivoDeEvolucao($params)
    {  
        $sql = "DELETE FROM MOTIEVOLCONT
                WHERE CDMOTIEVOCON   = :CDMOTIEVOCON
                    AND NRORG        = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }

    public function atualizarCrmMotivoDeEvolucao($params)
    {
        $sql = "UPDATE MOTIEVOLCONT
                SET NMANEXOPADRAO        = :NMANEXOPADRAO,
                    DSCAMINHOANEXOPADRAO = :DSCAMINHOANEXOPADRAO,
                    NRORG                = :NRORG,
                    DTULTATU             = SYSDATE,
                    NRORGULTATU          = :NRORGULTATU,
                    CDOPERULTATU         = :CDOPERULTATU
                WHERE CDMOTIEVOCON       = :CDMOTIEVOCON ";

        $this->connection->executeStatement($sql, $params);
    }
   
    public function getAnexoMotivoDeEvolucao(array $params)
    {
        $sql = "SELECT DSCAMINHOANEXOPADRAO,
                     NMANEXOPADRAO          
                FROM MOTIEVOLCONT
                WHERE CDMOTIEVOCON  = :CDMOTIEVOCON";

         return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function deleteAnexoMotivoDeEvolucao($params)
    {  
        $sql = "UPDATE MOTIEVOLCONT
                    SET DSCAMINHOANEXOPADRAO  = NULL,
                        NMANEXOPADRAO   = NULL
                  WHERE CDMOTIEVOCON = :CDMOTIEVOCON";
                  
        $std = $this->connection->prepare($sql, $params);
        $std->execute($params);
        
    }

}
