<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class CrmResultadoDaEvolucaoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCrmResultadoDaEvolucao()
    {
        $sql = "SELECT * FROM CRM_RESULTEVOL ORDER BY NRSEQRESULEVOL ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getVerificaCDResultadoDaEvolucao($params)
    {
        $sql = "SELECT COUNT(*)
                    AS VALIDA
                    FROM CRM_RESULTEVOL
                    WHERE NRSEQRESULEVOL = :NRSEQRESULEVOL";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];

       }

    public function insertCrmResultadoDaEvolucao( $params )
    {
        $sql = "INSERT INTO CRM_RESULTEVOL
                        (NRSEQRESULEVOL,
                          DESCRESULEVOL,
                          IDGERPROXATIV,
                        IDRESULTOPORTUNI,
                          IDRESULTCASO,
                          IDRESULTEVOLUCAO,
                          IDGANHAPERDE,
                          NRORG,
                          IDATIVO,
                          DTINCLUSAO,
                          DTULTATU,
                          NRORGINCLUSAO,
                          CDOPERINCLUSAO,
                          NRORGULTATU,
                          CDOPERULTATU)
                           VALUES (:NRSEQRESULEVOL,
                          :DESCRESULEVOL,
                          :IDGERPROXATIV,
                          :IDRESULTOPORTUNI,
                          :IDRESULTCASO,
                          :IDRESULTEVOLUCAO,
                          :IDGANHAPERDE,
                          :NRORG,
                          :IDATIVO,
                          SYSDATE,
                          SYSDATE,
                          :NRORGINCLUSAO,
                          :CDOPERINCLUSAO,
                          :NRORGULTATU,
                          :CDOPERULTATU)";
                        
                        

        $this->connection->executeStatement($sql, $params);
       
    }
    public function checkExistingResultadoDaEvolucao($params)
    {
        
        $sql = "SELECT
                    COUNT(*) AS VALIDA
                FROM
                    CRM_RESULTEVOL
                WHERE
                       UPPER (DESCRESULEVOL) = UPPER (:DESCRESULEVOL)
                       AND IDGERPROXATIV     = :IDGERPROXATIV 
                       AND IDRESULTOPORTUNI  = :IDRESULTOPORTUNI
                       AND IDRESULTCASO      = :IDRESULTCASO
                       AND IDRESULTEVOLUCAO  = :IDRESULTEVOLUCAO
                       AND IDGANHAPERDE      = :IDGANHAPERDE
                       AND NRORG             = :NRORG  
                       AND NRSEQRESULEVOL <> :NRSEQRESULEVOL";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }

    public function editCrmResultadoDaEvolucao( $params )
    {
        
        $sql = "UPDATE CRM_RESULTEVOL
                SET 
                    DESCRESULEVOL              = :DESCRESULEVOL,
                    IDGERPROXATIV              = :IDGERPROXATIV,
                    IDRESULTOPORTUNI           = :IDRESULTOPORTUNI,
                    IDRESULTCASO               = :IDRESULTCASO,
                    IDRESULTEVOLUCAO           = :IDRESULTEVOLUCAO,
                    IDGANHAPERDE               = :IDGANHAPERDE,
                    NRORG                      = :NRORG,
                    NRORGULTATU                = :NRORGULTATU,  
                    CDOPERULTATU               = :CDOPERULTATU,  
                    IDATIVO                    = :IDATIVO,
                    DTULTATU                   = SYSDATE
                WHERE NRSEQRESULEVOL             = :NRSEQRESULEVOL";
        $this->connection->executeStatement($sql, $params);

    }

    public function deleteCrmResultadoDaEvolucao($params)
    {  
        $sql = "DELETE FROM CRM_RESULTEVOL
                WHERE NRSEQRESULEVOL      = :NRSEQRESULEVOL  
                    AND NRORG             = :NRORG";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }

}
