<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class CrmTipoDeContatoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCrmTipoDeContato()
    {
        $sql = "SELECT * FROM TIPOCONT ORDER BY CDTIPOCONT ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getVerificaCDTipoContato($params)
    {
        $sql = "SELECT COUNT(*)
                    AS VALIDA
                    FROM TIPOCONT
                    WHERE CDTIPOCONT = :CDTIPOCONT";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];

       }

    public function insertCrmTipoDeContato( $params )
    {
        $sql = "INSERT INTO TIPOCONT
                       (CDTIPOCONT,
                        NMTIPOCONT,  
                        NRORG,
                        NRORGINCLUSAO,  
                        CDOPERINCLUSAO,
                        NRORGULTATU,  
                        CDOPERULTATU,    
                        IDATIVO,
                        DTINCLUSAO)        
                VALUES (:CDTIPOCONT,
                        :NMTIPOCONT,  
                        :NRORG,
                        :NRORGINCLUSAO,  
                        :CDOPERINCLUSAO,
                        :NRORGULTATU,  
                        :CDOPERULTATU,    
                        :IDATIVO, 
                        SYSDATE)";
        $this->connection->executeStatement($sql, $params);
       
    }
    public function checkExistingTipoDeContato($params)
    {
        
        $sql = "SELECT
                    COUNT(*) AS VALIDA
                FROM
                    TIPOCONT
                WHERE
                       UPPER (NMTIPOCONT) = UPPER (:NMTIPOCONT)
                    AND NRORG = :NRORG  AND CDTIPOCONT <> :CDTIPOCONT";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }

    public function editCrmTipoDeContato( $params )
    {
        
        $sql = "UPDATE TIPOCONT
                SET 
                    NMTIPOCONT                 = :NMTIPOCONT,
                    NRORG                      = :NRORG,
                    NRORGULTATU                = :NRORGULTATU,  
                    CDOPERULTATU               = :CDOPERULTATU,  
                    IDATIVO                    = :IDATIVO,
                    DTULTATU                   = SYSDATE
                WHERE CDTIPOCONT              = :CDTIPOCONT";
        $this->connection->executeStatement($sql, $params);

    }

    public function deleteCrmTipoDeContato($params)
    {  
        $sql = "DELETE FROM TIPOCONT
                WHERE CDTIPOCONT          = :CDTIPOCONT  
                    AND NRORG             = :NRORG";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }

}
