<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class InterlocutoresClienteFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getInterlocutoresCliente($params)
{
    $sql = "SELECT
                CDCLIENTE,
                NRINSJURCLIE, 
                NMRAZSOCCLIE, 
                NMFANTCLIE,
                NRORG,
                IDCLIEATIV   
            FROM
                CLIENTE
            WHERE 
                ((INSTR(:IDCLIEATIV, TO_CHAR(IDCLIEATIV)) > 0) 
                OR (:IDCLIEATIV = 'T'))
                ORDER BY NMFANTCLIE";

    // Executa a query, construindo e retornando os dados da resposta
    return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
}

public function getCliente()
    {
        $sql = "SELECT DISTINCT
                CDCLIENTE,
                NRINSJURCLIE, 
                NMRAZSOCCLIE, 
                NMFANTCLIE,
                NRORG,
                IDCLIEATIV   
            FROM
                CLIENTE            
                ORDER BY NMFANTCLIE";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getInterlocutorBasedOnCliente($params)
    {
                    $sql = "SELECT 
                                I.CDCLIENTE,
                                C.NMFANTCLIE,
                                I.CDINTECLIE,
                                I.NMINTECLIE,
                                I.DSCARGINCLIE,
                                I.CDPAIS,
                                P.NMPAIS,
                                I.SGESTADO,
                                E.NMESTADO,
                                I.CDMUNICIPIO,
                                M.NMMUNICIPIO, 
                                /* I.DTNASCINCLIE, */
                                TO_CHAR(I.DTNASCINCLIE, 'DD/MM/YYYY') AS DTNASCINCLIE,
                                I.NRTEL1INCLIE,
                                I.NRRAM1INCLIE,
                                I.NRTEL2INCLIE,
                                I.DSENDEINCLIE,
                                I.NMBAIRINCLIE,
                                I.NRCEPINCLIE,
                                I.DSEMAILICLIE,
                                I.NRCPFICLIE,
                                I.IDATIVO
                            FROM
                                INTECLIE I
                                    LEFT JOIN CLIENTE C  ON I.CDCLIENTE = C.CDCLIENTE
                                    LEFT JOIN PAIS P  ON I.CDPAIS = P.CDPAIS
                                    LEFT JOIN ESTADO E  ON (I.CDPAIS = E.CDPAIS) AND (I.SGESTADO = E.SGESTADO)
                                    LEFT JOIN MUNICIPIO M  ON (I.CDPAIS = M.CDPAIS) AND (I.SGESTADO = M.SGESTADO) AND (I.CDMUNICIPIO = M.CDMUNICIPIO)
                                    WHERE I.CDCLIENTE = :CDCLIENTE
                                    ORDER BY C.NMFANTCLIE, I.CDINTECLIE";

                    return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function insertCrmInterloCli($params)
    {
                    $sql = "INSERT INTO INTECLIE
                                        (CDCLIENTE, 
                                        CDINTECLIE,
                                        NMINTECLIE,
                                        NRCPFICLIE,
                                        DSCARGINCLIE,
                                        CDPAIS,
                                        SGESTADO,
                                        CDMUNICIPIO,
                                        DTNASCINCLIE,
                                        NRTEL1INCLIE,
                                        NRRAM1INCLIE,
                                        DSENDEINCLIE,
                                        NMBAIRINCLIE,
                                        NRCEPINCLIE,
                                        DSEMAILICLIE,
                                        NRORG,
                                        DTINCLUSAO,
                                        NRORGINCLUSAO,
                                        CDOPERINCLUSAO,
                                        NRORGULTATU,
                                        CDOPERULTATU, 
                                        IDATIVO
                                    ) VALUES (
                                        :CDCLIENTE,
                                        :CDINTECLIE,
                                        :NMINTECLIE,
                                        :NRCPFICLIE,
                                        :DSCARGINCLIE,
                                        :CDPAIS,
                                        :SGESTADO,
                                        :CDMUNICIPIO,
                                        :DTNASCINCLIE,
                                        :NRTEL1INCLIE,
                                        :NRRAM1INCLIE,
                                        :DSENDEINCLIE,
                                        :NMBAIRINCLIE,
                                        :NRCEPINCLIE,
                                        :DSEMAILICLIE,
                                        :NRORG,
                                        SYSDATE,
                                        :NRORGINCLUSAO,
                                        :CDOPERINCLUSAO,
                                        :NRORGULTATU,
                                        :CDOPERULTATU,
                                        :IDATIVO)";

        $this->connection->executeStatement($sql, $params);                                
    }

    public function saveEditCrmInterloCli( $params )
    {
        
        $sql = "UPDATE INTECLIE
                SET 
                    NMINTECLIE                 = :NMINTECLIE,
                    NRCPFICLIE                 = :NRCPFICLIE,
                    DSCARGINCLIE               = :DSCARGINCLIE,
                    CDPAIS                     = :CDPAIS,
                    SGESTADO                   = :SGESTADO,
                    CDMUNICIPIO                = :CDMUNICIPIO,
                    DTNASCINCLIE               = :DTNASCINCLIE,
                    NRTEL1INCLIE               = :NRTEL1INCLIE,
                    NRRAM1INCLIE               = :NRRAM1INCLIE,
                    DSENDEINCLIE               = :DSENDEINCLIE,
                    NMBAIRINCLIE               = :NMBAIRINCLIE,
                    NRCEPINCLIE                = :NRCEPINCLIE,
                    DSEMAILICLIE               = :DSEMAILICLIE,
                    NRORG                      = :NRORG,
                    DTULTATUINTC               = SYSDATE,
                    DTULTATU                   = SYSDATE,
                    NRORGULTATU                = :NRORGULTATU,
                    CDOPERULTATU               = :CDOPERULTATU,
                    IDATIVO                    = :IDATIVO
                WHERE CDINTECLIE                    = :CDINTECLIE AND
                      CDCLIENTE                     = :CDCLIENTE";

        $this->connection->executeStatement($sql, $params);

    }
    
    public function deleteCrmInterloCliFactory($params)
    {  
        $sql = "DELETE FROM INTECLIE
                        WHERE CDINTECLIE   = :CDINTECLIE
                            AND NRORG      = :NRORG
                            AND CDCLIENTE  = :CDCLIENTE"; 

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }

    public function getCountry($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    "CDPAIS AS CDPAIS",
                    "UPPER(NMPAIS) AS NMPAIS",
                    "DTULTATUPAIS",
                    "CDDDIPAIS",
                    "CDPAISEXPFIS",
                    "CDPAISBACEN",
                    "UPPER(SGPAIS) AS SGPAIS",
                    "CDPAISGMB",
                    "NRORG",
                    "DTINCLUSAO",
                    "DTULTATU",
                    "NRORGINCLUSAO",
                    "CDOPERINCLUSAO",
                    "NRORGULTATU",
                    "CDOPERULTATU",
                    "IDATIVO"
                ])
                ->from('PAIS')
                ->where($queryBuilder->expr()->eq('NRORG', ':NRORG'))
                ->orderBy('NMPAIS', 'ASC');

            $queryBuilder->setParameter('NRORG', $params["NRORG"]);
            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function getState($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    "ESTADO.CDPAIS",
                    "PAIS.NMPAIS",
                    "ESTADO.SGESTADO",
                    "ESTADO.NMESTADO",
                    "ESTADO.CDESTAEXPO",
                    "ESTADO.DTULTATUESTA",
                    "ESTADO.CDESTADOIBGE",
                    "ESTADO.IDUTHORVER",
                    "ESTADO.HRDIFUTCFUSO",
                    "ESTADO.NRORG",
                    "ESTADO.DTINCLUSAO",
                    "ESTADO.DTULTATU",
                    "ESTADO.NRORGINCLUSAO",
                    "ESTADO.CDOPERINCLUSAO",
                    "ESTADO.NRORGULTATU",
                    "ESTADO.CDOPERULTATU",
                    "ESTADO.IDATIVO",
                    "ESTADO.CDESTADOGMB"
                ])
                ->from('ESTADO', 'ESTADO')
                ->leftJoin('ESTADO', 'PAIS', 'PAIS', 'ESTADO.CDPAIS = PAIS.CDPAIS AND ESTADO.NRORG = PAIS.NRORG')
                ->where($queryBuilder->expr()->eq('ESTADO.NRORG', ':NRORG'))
                ->orderBy('NMESTADO', 'ASC');

            $queryBuilder->setParameter('NRORG', $params["NRORG"]);
            if ($params["CDPAIS"] !== null) {
                $queryBuilder->andWhere($queryBuilder->expr()->in('PAIS.CDPAIS', ':CDPAIS'))
                    ->setParameter('CDPAIS', $params["CDPAIS"]);
            }
            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

    public function getMunicipality($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    "MUNICIPIO.CDPAIS",
                    "PAIS.NMPAIS",
                    "MUNICIPIO.SGESTADO",
                    "ESTADO.NMESTADO",
                    "MUNICIPIO.CDMUNICIPIO",
                    "MUNICIPIO.NMMUNICIPIO",
                    "MUNICIPIO.CDMUNICIBGE",
                    "MUNICIPIO.IDMUNIALC",
                    "MUNICIPIO.CDMUNIEXPO",
                    "MUNICIPIO.DTULTATUMUNI",
                    "MUNICIPIO.CDREGIAO",
                    "MUNICIPIO.CDDDDMUNICIP",
                    "MUNICIPIO.IDMUNIUTCONVNFE",
                    "MUNICIPIO.CDMUNICIPIOGMB",
                    "MUNICIPIO.NRORG",
                    "MUNICIPIO.DTINCLUSAO",
                    "MUNICIPIO.DTULTATU",
                    "MUNICIPIO.NRORGINCLUSAO",
                    "MUNICIPIO.CDOPERINCLUSAO",
                    "MUNICIPIO.NRORGULTATU",
                    "MUNICIPIO.CDOPERULTATU",
                    "MUNICIPIO.IDATIVO",
                    "MUNICIPIO.CDMUNICSIAFI"
                ])
                ->from('MUNICIPIO', 'MUNICIPIO')
                ->leftJoin('MUNICIPIO', 'PAIS', 'PAIS', 'MUNICIPIO.CDPAIS = PAIS.CDPAIS AND MUNICIPIO.NRORG = PAIS.NRORG')
                ->leftJoin('MUNICIPIO', 'ESTADO', 'ESTADO', 'MUNICIPIO.SGESTADO = ESTADO.SGESTADO AND MUNICIPIO.NRORG = ESTADO.NRORG')
                ->where(
                    $queryBuilder->expr()->and(
                        $queryBuilder->expr()->in('MUNICIPIO.NRORG', ':NRORG'),
                    )
                )
                ->orderBy('MUNICIPIO.NMMUNICIPIO', 'ASC');

            $queryBuilder->setParameter('NRORG', $params["NRORG"]);
            if ($params["CDPAIS"] !== null && $params["SGESTADO"] !== null) {
                $queryBuilder->andWhere($queryBuilder->expr()->in('PAIS.CDPAIS', ':CDPAIS'))
                    ->andWhere($queryBuilder->expr()->in('ESTADO.SGESTADO', ':SGESTADO'))
                    ->setParameter('CDPAIS', $params["CDPAIS"], Connection::PARAM_STR_ARRAY)
                    ->setParameter('SGESTADO', $params["SGESTADO"], Connection::PARAM_STR_ARRAY);
            }
            $result = $this->createAndExecuteQueryAndBuildResponseData(
                $this->entityManager,
                $queryBuilder->getSQL(),
                $queryBuilder->getParameters()
            );

            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    } 

    public function getNeighborhood($params)
    {
        try {
            $queryBuilder = $this->connection->createQueryBuilder();
            $queryBuilder
                ->select([
                    "BAIRRO.NRORG",
                    "BAIRRO.CDPAIS",
                    "BAIRRO.SGESTADO",
                    "BAIRRO.CDMUNICIPIO",
                    "BAIRRO.CDREGIAOMUNI",
                    "BAIRRO.CDBAIRRO",
                    "BAIRRO.NMBAIRRO",
                    "BAIRRO.VRTXENTREGA",
                    "BAIRRO.QTHORAENTREGA",
                    "REGIAOMUNI.NMREGIAOMUNI"
                ])
                ->from('BAIRRO', 'BAIRRO')
                ->leftJoin('BAIRRO', 'REGIAOMUNI', 'REGIAOMUNI', 'BAIRRO.CDPAIS = REGIAOMUNI.CDPAIS AND BAIRRO.SGESTADO = REGIAOMUNI.SGESTADO AND BAIRRO.CDMUNICIPIO = REGIAOMUNI.CDMUNICIPIO AND BAIRRO.CDREGIAOMUNI = REGIAOMUNI.CDREGIAOMUNI AND BAIRRO.NRORG = REGIAOMUNI.NRORG')
                ->where(
                    $queryBuilder->expr()->and(
                        $queryBuilder->expr()->eq('BAIRRO.NRORG', ':NRORG'),
                    )
                )
                ->orderBy('BAIRRO.NMBAIRRO', 'ASC');

            $queryBuilder->setParameter('NRORG', $params["NRORG"]);

            $queryBuilder->setParameter('NRORG', $params["NRORG"]);
            if ($params["CDPAIS"] !== null && $params["SGESTADO"] !== null && $params["CDMUNICIPIO"] !== null) {
                $queryBuilder->andWhere($queryBuilder->expr()->in('BAIRRO.CDPAIS', ':CDPAIS'))
                    ->andWhere($queryBuilder->expr()->in('BAIRRO.SGESTADO', ':SGESTADO'))
                    ->andWhere($queryBuilder->expr()->in('BAIRRO.CDMUNICIPIO', ':CDMUNICIPIO'))
                    ->setParameter('CDPAIS', $params["CDPAIS"], Connection::PARAM_STR_ARRAY)
                    ->setParameter('SGESTADO', $params["SGESTADO"], Connection::PARAM_STR_ARRAY)
                    ->setParameter('CDMUNICIPIO', $params["CDMUNICIPIO"], Connection::PARAM_STR_ARRAY);
            }

            $result = $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
            return $result;
        } catch (\Throwable $e) {
            echo 'Ocorreu uma exceção: ' . $e->getMessage();
            throw $e;
        }
    }

}