<?php

namespace CRM\Service;

use CRM\Factory\CrmMotivoDeEvolucaoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use CRM\Service\FileServerService;

class CrmMotivoDeEvolucaoService
{

    protected $MotivoDeEvolucaoFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;
    protected $fileServerService;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmMotivoDeEvolucaoFactory $MotivoDeEvolucaoFactory, FileServerService $fileServerService)
    {
        $this->MotivoDeEvolucaoFactory      = $MotivoDeEvolucaoFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
        $this->fileServerService            = $fileServerService;
    }

    public function getCrmMotivoDeEvolucao()
    {
        return $this->MotivoDeEvolucaoFactory->getCrmMotivoDeEvolucao();
    }

    public function saveCrmMotivoDeEvolucao($rows)
    { 
       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();

        foreach ($rows["DRG"] as $row) {
            if ($row["CDMOTIEVOCON"] == 0) {
                $this->checkExistingMotivoDeEvolucao($nrorg, $row);
                $novoCodigo = $this->newCode->getCodeByTableName("MOTIEVOLCONT", $nrorg, 1, 5, false);

                    $params = array(
                    "CDMOTIEVOCON"   => $novoCodigo,
                    "NMMOTIEVOCON"   => $row["NMMOTIEVOCON"],
                    "IDENVIAEMAIL"   => $row["IDENVIAEMAIL"],
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->MotivoDeEvolucaoFactory->insertCrmMotivoDeEvolucao($params);
            } else {
                $this->checkExistingMotivoDeEvolucao($nrorg, $row);
                $params = array(
                    "CDMOTIEVOCON"   => $row["CDMOTIEVOCON"],
                    "NMMOTIEVOCON"   => $row["NMMOTIEVOCON"],
                    "IDENVIAEMAIL"   => $row["IDENVIAEMAIL"],
                    "NRORGULTATU"       => $nrorg,
                    "NRORG"             => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->MotivoDeEvolucaoFactory->editCrmMotivoDeEvolucao($params);

            }
            }
            
             $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function checkExistingMotivoDeEvolucao ($nrorg, $row)
    {
        try {
            $params = array(
                "CDMOTIEVOCON"   => $row["CDMOTIEVOCON"],
                "NMMOTIEVOCON"   => $row["NMMOTIEVOCON"],
                "IDENVIAEMAIL"   => $row["IDENVIAEMAIL"],
                "NRORG"          => $nrorg,
            );
            
            $existe =  $this->MotivoDeEvolucaoFactory->checkExistingMotivoDeEvolucao($params);
            if ($existe > 0 ) {
                throw new \Exception("EXISTE");
            }
        } catch (\Exception $ex) {
            throw $ex;
        }
    }

    public function deleteCrmMotivoDeEvolucao ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "CDMOTIEVOCON"   => $item["CDMOTIEVOCON"],
                    "NRORG"          => $nrorg,
                );

                $this->MotivoDeEvolucaoFactory->deleteCrmMotivoDeEvolucao($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }


    public function inserirAnexoMotivoEvolucao($parametros)
    {
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();
        $this->connection->beginTransaction();
        try {
            if (count($parametros['ARQUIVO']) > 0) {
                $dados = $this->fileServerService->uploadFiles($parametros['ARQUIVO'], 'anexo_modelo_documento_proposta');
                $dados[0]["size"] = $dados[0]["size"]/1024;
            } else {
                $dados = [[
                    "path" => $parametros["DSCAMINHOANEXOPADRAO"],
                    "size" => $parametros["VRTAMANHO"],
                    "name" => $parametros["NMARQUIVO"],
                    "type" => $parametros["DSTIPO"],
                ]];
            }
            if ($parametros["CDMOTIEVOCON"] != NULL) {
                $params = array(
                    "CDMOTIEVOCON"          => $parametros['CDMOTIEVOCON'],
                    "NMANEXOPADRAO"         => $dados[0]['name'],
                    "DSCAMINHOANEXOPADRAO"  => $dados[0]['path'],
                    "NRORG"                 => $nrorg,
                    "NRORGULTATU"           => $nrorg,
                    "CDOPERULTATU"          => $cdoperador,
                );
                $this->MotivoDeEvolucaoFactory->atualizarCrmMotivoDeEvolucao($params);
            } else {
                throw new \Exception("Não foi possível inserir o anexo para o motivo de evolução selecionado!");
            }
            
        
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }

    }

    public function downloadAnexoMotivoDeEvolucao($cdmotievocon)
    {
        $param = array(
                "CDMOTIEVOCON" => $cdmotievocon
        );

        $dados = $this->MotivoDeEvolucaoFactory->getAnexoMotivoDeEvolucao($param);
        $url = $this->fileServerUrl."/files/".$dados["data"][0]['DSCAMINHOANEXOPADRAO'];
        $nomeArquivo = $dados["data"][0]['NMANEXOPADRAO'];

        $file = @fileget_contents($url);
        if ($file) {
            Utilities::downloadArquivoFileServer($url, $nomeArquivo);
        } else {
            $this->downloadDocFileServer($cdmotievocon);
        }
    }

    public function downloadDocFileServer($cdmotievocon)
    {
        $paramsAux = array (
            "CDMOTIEVOCON" => $cdmotievocon,
        );

        $documento = $this->MotivoDeEvolucaoFactory->getAnexoMotivoDeEvolucao($paramsAux);
        if (!empty($documento["data"][0]["DSCAMINHOANEXOPADRAO"])) {
            $microtime = microtime(true);
            $microtime = str_replace(".", "", $microtime);

            $url = $this->fileServerUrl."/files/".$documento["data"][0]['DSCAMINHOANEXOPADRAO'];
            $fileName  = $microtime . "" . str_replace(",", "", $documento["data"][0]["NMANEXOPADRAO"]);

            Utilities::downloadArquivoFileServer($url, $fileName);
        }
    }

    public function deleteAnexoMotivoDeEvolucao($params)
    {
        $this->connection->beginTransaction();
        try {
            $row = $params["row"];
            $param = array(
                "CDMOTIEVOCON" => $row["CDMOTIEVOCON"]
            );
            $this->fileServerService->deleteFile($row["DSCAMINHOANEXOPADRAO"]);
            $this->MotivoDeEvolucaoFactory->deleteAnexoMotivoDeEvolucao($param);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}