<?php

namespace CRM\Service;

use CRM\Factory\CrmResultadoDaEvolucaoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmResultadoDaEvolucaoService
{

    protected $ResultadoDaEvolucaoFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmResultadoDaEvolucaoFactory $ResultadoDaEvolucaoFactory)
    {
        $this->ResultadoDaEvolucaoFactory         = $ResultadoDaEvolucaoFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getCrmResultadoDaEvolucao()
    {
        return $this->ResultadoDaEvolucaoFactory->getCrmResultadoDaEvolucao();
    }

    public function saveCrmResultadoDaEvolucao($rows)
    { 
       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();

        foreach ($rows["DRG"] as $row) {
            if ($row["NRSEQRESULEVOL"] == 0) {
                $this->checkExistingResultadoDaEvolucao($nrorg, $row);
                $novoCodigo = $this->newCode->getCodeByTableName("CRM_RESULTEVOL", $nrorg, 1, 5, false);
                $params = array(
                    "NRSEQRESULEVOL"    => $novoCodigo,
                    "DESCRESULEVOL"     => $row["DESCRESULEVOL"],
                    "IDGERPROXATIV"     => $row["IDGERPROXATIV"],
                    "IDRESULTOPORTUNI"  => $row["IDRESULTOPORTUNI"],
                    "IDRESULTCASO"      => $row["IDRESULTCASO"],
                    "IDRESULTEVOLUCAO"  => $row["IDRESULTEVOLUCAO"],
                    "IDGANHAPERDE"      => $row["IDGANHAPERDE"], 
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->ResultadoDaEvolucaoFactory->insertCrmResultadoDaEvolucao($params);
            } else {
                $this->checkExistingResultadoDaEvolucao($nrorg, $row);
                $params = array(
                    "NRSEQRESULEVOL"    => $row["NRSEQRESULEVOL"],
                    "DESCRESULEVOL"     => $row["DESCRESULEVOL"],
                    "IDGERPROXATIV"     => $row["IDGERPROXATIV"],
                    "IDRESULTOPORTUNI"  => $row["IDRESULTOPORTUNI"],
                    "IDRESULTCASO"      => $row["IDRESULTCASO"],
                    "IDRESULTEVOLUCAO"  => $row["IDRESULTEVOLUCAO"],
                    "IDGANHAPERDE"      => $row["IDGANHAPERDE"],   
                    "NRORGULTATU"       => $nrorg,
                    "NRORG"             => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->ResultadoDaEvolucaoFactory->editCrmResultadoDaEvolucao($params);

            }
            }
            
             $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function checkExistingResultadoDaEvolucao ($nrorg, $row)
    {
        try {
            $dataparams = array(
                "NRSEQRESULEVOL"    => $row["NRSEQRESULEVOL"],
                "DESCRESULEVOL"     => $row["DESCRESULEVOL"],
                "IDGERPROXATIV"     => $row["IDGERPROXATIV"],
                "IDRESULTOPORTUNI"  => $row["IDRESULTOPORTUNI"],
                "IDRESULTCASO"      => $row["IDRESULTCASO"],
                "IDRESULTEVOLUCAO"  => $row["IDRESULTEVOLUCAO"],
                "IDGANHAPERDE"      => $row["IDGANHAPERDE"],
                "NRORG"             => $nrorg
            );

            $existe =  $this->ResultadoDaEvolucaoFactory->checkExistingResultadoDaEvolucao($dataparams);
            if ($existe > 0 ) {
                throw new \Exception(" O Registro inserido já existe!");
            }
        } catch (\Exception $ex) {
            throw $ex;
        }
    }
    public function deleteCrmResultadoDaEvolucao ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "NRSEQRESULEVOL"    =>  $item["NRSEQRESULEVOL"],
                    "NRORG"             => $nrorg,
                );

                $this->ResultadoDaEvolucaoFactory->deleteCrmResultadoDaEvolucao($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}