<?php

namespace CRM\Service;

use CRM\Factory\CrmTipoDeContatoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmTipoDeContatoService
{

    protected $TipoDeContatoFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmTipoDeContatoFactory $TipoDeContatoFactory)
    {
        $this->TipoDeContatoFactory         = $TipoDeContatoFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getCrmTipoDeContato()
    {
        return $this->TipoDeContatoFactory->getCrmTipoDeContato();
    }

    private function getNovoCodigoTipoDeContato()
    {
        do {
            $codigo = $this->getRandomString();
      
            $params = array(
                'CDTIPOCONT' => $codigo
            );
    
            $existing = $this->TipoDeContatoFactory->getVerificaCDTipoContato($params); 
        } while ($existing != 0);
        return $codigo;
    }

    private function getRandomString() {
        // Defina os caracteres permitidos
        $characters = '123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    
        // Gera a string aleatória de 2 caracteres
        $randomString = '';
        for ($i = 0; $i < 2; $i++) {
            $index = rand(0, strlen($characters) - 1);
            $randomString .= $characters[$index];
        }
    
        return $randomString;
    }

    public function saveCrmTipoDeContato($rows)
    { 
       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();

        foreach ($rows["DRG"] as $row) {
            if ($row["CDTIPOCONT"] == '0') {
                $this->checkExistingTipoDeContato($nrorg, $row);
            
                $novoCodigo = $this->getNovoCodigoTipoDeContato();

                $params = array(
                    "CDTIPOCONT"   => $novoCodigo,
                    "NMTIPOCONT"   => $row["NMTIPOCONT"],
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->TipoDeContatoFactory->insertCrmTipoDeContato($params);
            } else {
                $this->checkExistingTipoDeContato($nrorg, $row);
                $params = array(
                    "CDTIPOCONT"   => $row["CDTIPOCONT"],
                    "NMTIPOCONT"   => $row["NMTIPOCONT"],
                    "NRORGULTATU"       => $nrorg,
                    "NRORG"             => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->TipoDeContatoFactory->editCrmTipoDeContato($params);

            }
        }
            
        $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function checkExistingTipoDeContato ($nrorg, $row)
    {
        try {
            $dataparams = array(
                "CDTIPOCONT"   => $row["CDTIPOCONT"],
                "NMTIPOCONT"   => $row["NMTIPOCONT"],
                "NRORG"        => $nrorg
            );

            $existe =  $this->TipoDeContatoFactory->checkExistingTipoDeContato($dataparams);
            if ($existe > 0 ) {
                throw new \Exception(" O Registro inserido já existe!");
            }
        } catch (\Exception $ex) {
            throw $ex;
        }
    }
    public function deleteCrmTipoDeContato ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "CDTIPOCONT"        =>  $item["CDTIPOCONT"],
                    "NRORG"             => $nrorg,
                );

                $this->TipoDeContatoFactory->deleteCrmTipoDeContato($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}