<?php

namespace CRM\Service;

use CRM\Factory\InterlocutoresClienteFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class InterlocutoresClienteService
{

    protected $InterlocutoresClienteFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, InterlocutoresClienteFactory $InterlocutoresClienteFactory)
    {
        $this->InterlocutoresClienteFactory         = $InterlocutoresClienteFactory;
        $this->Environment                          = $Environment;
        $this->newCode                              = $newCode;
        $this->connection                           = $entityManager->getConnection();
    }

    public function getInterlocutoresCliente($params)
    {
        // debugApi([$params]); //
        $dynamicFilter = json_decode(utf8_encode(base64_decode($params['dynamic_filter'])),true);
        // debugApi([$dynamicFilter]); //

        $parametros = array(
            "IDCLIEATIV" => isset($dynamicFilter["IDCLIEATIV"][0]) ? $dynamicFilter["IDCLIEATIV"][0]['value'] : NULL,
        );        
        
        // Retorna os interlocutores do cliente através da factory
        return $this->InterlocutoresClienteFactory->getInterlocutoresCliente($parametros);
    }

    public function getCliente()
    {
        return $this->InterlocutoresClienteFactory->getCliente();
    }

    public function getInterlocutorBasedOnCliente($params)
    {
        $parametros = array(
            "CDCLIENTE" => $params["CDCLIENTE"],
        );

            return $this->InterlocutoresClienteFactory->getInterlocutorBasedOnCliente($parametros);
    }

    public function getCountry()
    {
        $nrorg = $this->Environment->getNrorg();
        try {
            $params = array(
                "NRORG" => $nrorg,
            );
            return $this->InterlocutoresClienteFactory->getCountry($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getState($params)
    {
        try {
            $cdpais = isset($params["CDPAIS"]) ? $params["CDPAIS"] : null;
            $paramsForQuery = array(
                "NRORG" => $this->Environment->getNrorg(),
                "CDPAIS" => $cdpais,
            );

            return $this->InterlocutoresClienteFactory->getState($paramsForQuery);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getMunicipality($params)
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $cdpais = isset($params["CDPAIS"]) ? $params["CDPAIS"] : null;
            $sgestado = isset($params["SGESTADO"]) ? $params["SGESTADO"] : null;

            $params = array(
                "NRORG"    => $nrorg,
                "CDPAIS"   => $cdpais,
                "SGESTADO" => $sgestado,

            );
            return $this->InterlocutoresClienteFactory->getMunicipality($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getNeighborhood($params)
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $cdpais = isset($params["CDPAIS"]) ? $params["CDPAIS"] : null;
            $sgestado = isset($params["SGESTADO"]) ? $params["SGESTADO"] : null;
            $cdmunicipio = isset($params["CDMUNICIPIO"]) ? $params["CDMUNICIPIO"] : null;

            $params = array(
                "NRORG"    => $nrorg,
                "CDPAIS"   => $cdpais,
                "SGESTADO" => $sgestado,
                "CDMUNICIPIO" => $cdmunicipio,
            );
            return $this->InterlocutoresClienteFactory->getNeighborhood($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    
    public function saveCrmInterloCli($rows)
    { 
       $this->connection->beginTransaction();
       try{

        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();
                
   /* var_dump($rows);
    die;*/

        if ($rows["CDINTECLIE"]=='NOVO_REGISTRO') {
                $novoCodigo = $this->newCode->getCodeByTableName("INTECLIE", $nrorg, 1, 2, false);

                    $params = array(
                    "CDINTECLIE"        => $novoCodigo,
                    "NMINTECLIE"        => $rows["NMINTECLIE"],
                    "CDCLIENTE"         => $rows["CDCLIENTE"],
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "NRCPFICLIE"        => $rows["NRCPFICLIE"],
                    "DSCARGINCLIE"      => $rows["DSCARGINCLIE"],
                    "DSEMAILICLIE"      => $rows["DSEMAILICLIE"],
                    "NRTEL1INCLIE"      => $rows["NRTEL1INCLIE"],
                    "NRRAM1INCLIE"      => $rows["NRRAM1INCLIE"],
                    "NRCEPINCLIE"       => $rows["NRCEPINCLIE"],
                    "DSENDEINCLIE"      => $rows["DSENDEINCLIE"],
                    "CDPAIS"            => $rows["CDPAIS"],
                    "SGESTADO"          => $rows["SGESTADO"],
                    "CDMUNICIPIO"       => $rows["CDMUNICIPIO"],
                    "NMBAIRINCLIE"      => $rows["NMBAIRINCLIE"],
                    "DTNASCINCLIE"      => $rows["DTNASCINCLIE"],
                    "IDATIVO"           => $rows["IDATIVO"],
                    
                );
                /*debugApi([$params]);*/

                $this->InterlocutoresClienteFactory->insertCrmInterloCli($params);
            } else {
             
                $params = array(
                    "CDINTECLIE"        => $rows["CDINTECLIE"],
                    "NMINTECLIE"        => $rows["NMINTECLIE"],
                    "CDCLIENTE"         => $rows["CDCLIENTE"],
                    "NRORG"             => $nrorg,
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "NRCPFICLIE"        => $rows["NRCPFICLIE"],
                    "DSCARGINCLIE"      => $rows["DSCARGINCLIE"],
                    "DSEMAILICLIE"      => $rows["DSEMAILICLIE"],
                    "NRTEL1INCLIE"      => $rows["NRTEL1INCLIE"],
                    "NRRAM1INCLIE"      => $rows["NRRAM1INCLIE"],
                    "NRCEPINCLIE"       => $rows["NRCEPINCLIE"],
                    "DSENDEINCLIE"      => $rows["DSENDEINCLIE"],
                    "CDPAIS"            => $rows["CDPAIS"],
                    "SGESTADO"          => $rows["SGESTADO"],
                    "CDMUNICIPIO"       => $rows["CDMUNICIPIO"],
                    "NMBAIRINCLIE"      => $rows["NMBAIRINCLIE"],
                    "DTNASCINCLIE"      => $rows["DTNASCINCLIE"],
                    "IDATIVO"           => $rows["IDATIVO"],
                    
                );
                /*debugApi([$params]);*/

                $this->InterlocutoresClienteFactory->saveEditCrmInterloCli($params);
            
            
        }  
                $this->connection->commit();       
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
     
    } 

    public function deleteCrmInterloCliService ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "CDINTECLIE"  => $item["CDINTECLIE"],
                    "NRORG"       => $nrorg,
                    "CDCLIENTE"   => $item["CDCLIENTE"]
                    

                );

                $this->InterlocutoresClienteFactory->deleteCrmInterloCliFactory($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
  
}

