import {
  Config, Http, IEventParam, Metadata,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import {
  Button,
  DialogService,
  Form, LoadingService, Modal, ModalService, TextInput,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';

export class CrmMotivoDeEvolucaoController {
  private tekGridMotivoDeEvolucaoVisible: boolean = true;

  private currentRow: any = {};

  public modalText: string = '';

  private modal!: Modal;

  private editingGrid: boolean = false;

  get tituloFrame() {
    return this.currentRow.NMMOTIEVOCON;
  }

  get frameVisible() {
    return !this.tekGridMotivoDeEvolucaoVisible;
  }

  public async createModal() {
    this.modal = await ModalService.createFromJson('crm_configuracoes_de_evolucao/Modal/modal_motivo_de_evolucao', true);
    this.modal.show();
  }

  public destroyModal() {
    this.modal.destroy();
  }

  public async openModal({ row }: any) {
    await this.createModal();
    Metadata.getInstance<TextInput>('CDMOTIEVOCON').value = row.CDMOTIEVOCON;
  }

  public closeModal() {
    this.modal.hide();
  }

  public addNewRow() {
    const newId = 0;
    this.editingGrid = true;
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmMotivoDeEvolucao_grid');
    grid.addNewRow({ CDMOTIEVOCON: newId, IDENVIAEMAIL: 'N', IDATIVO: 'S' }, 'start').then(() => {
      setTimeout(() => {
        const nameInput = Metadata.getInstance<TextInput>(`NMMOTIEVOCON_editable_${newId}`);
        nameInput.setFocus();
      }, 500);
    });
  }

  public cancelEdit() {
    this.editingGrid = false;
  }

  public saveCrmMotivoDeEvolucao({ component, event }: IEventParam<TekGrid>) {
    event?.preventDefault();
    console.warn(component);
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveCrmMotivoDeEvolucao', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        this.cancelEdit();
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public messageConfirmDeleteCrmMotivoDeEvolucao({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmMotivoDeEvolucaoController.deleteCrmMotivoDeEvolucao');
  }

  public deleteCrmMotivoDeEvolucao() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmMotivoDeEvolucao_grid');
    LoadingService.show();
    Http.post('/deleteCrmMotivoDeEvolucao', {
      NRS: grid.selectedRows,
    }).then(() => {
      grid.selectedRows = [];
      grid.reload();
      Utilities.showSuccessMessage();
    }).catch((error) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }

  public async inserirAnexoMotivoEvolucao() {
    const form = Metadata.getInstance<Form>('form-adicionar-anexo');
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmMotivoDeEvolucao_grid');
    if (Utilities.validateForm(form)) {
      const file = await Utilities.buildArrayToUpload('ARQUIVO');
      LoadingService.show();
      const params = {
        CDMOTIEVOCON: Metadata.getInstance<TextInput>('CDMOTIEVOCON').value,
        ARQUIVO: file,
      };
      Http.post('/inserirAnexoMotivoEvolucao', params).then(() => {
        this.closeModal();
        grid.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        LoadingService.hide();
      });
    }
  }

  public changeButtonDeleteEditGrid({ row }: any) {
    if ((row.NMANEXOPADRAO === null) || (this.editingGrid === true)) {
      return true;
    }
    return false;
  }

  public changeButtonUploadGrid({ row }: any) {
    if ((row.NMANEXOPADRAO != null) || (this.editingGrid === true)) {
      return true;
    }
    return false;
  }

  public downloadAnexoMotivoDeEvolucao({ row }: any) {
    const cdmotievocon = row.CDMOTIEVOCON;
    window.open(`${Config.endPoint}downloadAnexoMotivoDeEvolucao?cdmotievocon=${cdmotievocon}`);
  }

  public dialoglimparAnexoMotivoDeEvolucao({ row }: IEventParam<Button>) {
    DialogService.show({
      name: 'dialog-deletar-anexo-proposta',
      type: 'warning',
      title: 'Atenção',
      text: 'Deseja realmente excluir o documento anexado?',
      buttons: [
        {
          name: 'NAO',
          component: 'ZdButton',
          label: 'Não',
          outline: true,
          events: {
            click: () => {
              DialogService.hide();
            },
          },
        },
        {
          name: 'SIM',
          component: 'ZdButton',
          label: 'Sim',
          events: {
            click: () => {
              this.deleteAnexoMotivoDeEvolucao({ row });
              DialogService.hide();
            },
          },
        },
      ],
    });
  }

  public deleteAnexoMotivoDeEvolucao({ row }: any) {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmMotivoDeEvolucao_grid');
    LoadingService.show();
    Http.post('/deleteAnexoMotivoDeEvolucao', {
      row,
    }).then(() => {
      grid.reload();
      Utilities.showSuccessMessage();
    }).catch((error) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
