import { Utilities } from '@/util/Utilities';
import { TextInput, LoadingService, DialogService } from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmResultadoDaEvolucaoController {
  private tekGridTipoDeContatoVisible: boolean = true;

  private currentRow: any = {};

  get tituloFrame() {
    return this.currentRow.NMTIPOCONT;
  }

  get frameVisible() {
    return !this.tekGridTipoDeContatoVisible;
  }

  public addNewRow() {
    const newId = 0;
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmResultadoDaEvolucao_grid');
    grid.addNewRow({
      NRSEQRESULEVOL: newId, IDATIVO: 'S', IDGERPROXATIV: 'N', IDRESULTOPORTUNI: 'NAO', IDRESULTCASO: 'NAO', IDRESULTEVOLUCAO: 'NAO', IDGANHAPERDE: 'PERDE',
    }, 'start').then(() => {
      setTimeout(() => {
        const nameInput = Metadata.getInstance<TextInput>(`DESCRESULEVOL_editable_${newId}`);
        nameInput.setFocus();
      }, 200);
    });
  }

  public saveResultadoDaEvolucao({ component, event }: IEventParam<TekGrid>) {
    event?.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveCrmResultadoDaEvolucao', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public messageConfirmDeleteResultadoDaEvolucao({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmResultadoDaEvolucaoController.deleteResultadoDaEvolucao');
  }

  public deleteResultadoDaEvolucao() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmResultadoDaEvolucao_grid');
    LoadingService.show();
    Http.post('/deleteCrmResultadoDaEvolucao', {
      NRS: grid.selectedRows,
    }).then(() => {
      grid.selectedRows = [];
      grid.reload();
      Utilities.showSuccessMessage();
    }).catch((error) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
