import { Utilities } from '@/util/Utilities';
import { TextInput, LoadingService, DialogService } from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmTipoDeContatoController {
  private tekGridTipoDeContatoVisible: boolean = true;

  private currentRow: any = {};

  get tituloFrame() {
    return this.currentRow.NMTIPOCONT;
  }

  get frameVisible() {
    return !this.tekGridTipoDeContatoVisible;
  }

  public addNewRow() {
    const newId = '0';
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmTipoDeContato_grid');
    grid.addNewRow({ CDTIPOCONT: newId, IDATIVO: 'S' }, 'start').then(() => {
      setTimeout(() => {
        const nameInput = Metadata.getInstance<TextInput>(`NMTIPOCONT_editable_${newId}`);
        nameInput.setFocus();
      }, 200);
    });
  }

  public saveCrmTipoDeContato({ component, event }: IEventParam<TekGrid>) {
    event?.preventDefault();
    if (Utilities.validateGrid(component)) {
      LoadingService.show();
      Http.post('/saveCrmTipoDeContato', {
        DRG: component.getEditedRows(),
      }).then(() => {
        component.datasource.get();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        Utilities.showErrorMessage(error);
      }).finally(() => {
        component.cancelEditedRows();
        LoadingService.hide();
      });
    }
  }

  public messageConfirmDeleteCrmTipoDeContato({ event }: any) {
    Utilities.showConfirmDeleteMessage(event, 'CrmTipoDeContatoController.deleteCrmTipoDeContato');
  }

  public deleteCrmTipoDeContato() {
    const grid = Metadata.getInstance<TekGrid>('tek-grid-CrmTipoDeContato_grid');
    LoadingService.show();
    Http.post('/deleteCrmTipoDeContato', {
      NRS: grid.selectedRows,
    }).then(() => {
      grid.selectedRows = [];
      grid.reload();
      Utilities.showSuccessMessage();
    }).catch((error) => {
      Utilities.showErrorMessage(error);
    }).finally(() => {
      LoadingService.hide();
      DialogService.hide();
    });
  }
}
